#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import re
import ConfigParser

from StringIO import StringIO

from aam.utils import md_to_html
from aam.options import hub

def read_config():
    config_path = os.path.join(hub.site.path, 'config.ini')
    if not os.path.exists(config_path):
        print("Can't find any config file.")
        return

    parser = ConfigParser.SafeConfigParser()
    parser.read(config_path)

    hub.site.name = parser.get("settings", "site_name").decode('utf-8')
    hub.site.owner = parser.get("settings", "site_owner").decode('utf-8')
    hub.site.url = parser.get("settings", "site_url").decode('utf-8')

def read_page():
    page_list = []
    all_pages = os.listdir(hub.site.page_path)
    os.chdir(hub.site.page_path)
    for page in all_pages:
        if page.split('.')[1] != 'md':
            continue
        page_content = {"title": "", "date": "", "description": "","content": ""}
        p = open(page).read()
        metas = p.split('----')[0].strip()
        for meta in StringIO(metas):
            try:
                name, value = meta.split(':')
                name = name.strip().lower()
                page_content[name.strip()] = value.strip()
            except:
                pass
        page_content["content"] = md_to_html(p.split('----')[1].strip())
        page_list.append(page_content)
    hub.site.pages = page_list



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

from aam.utils import to_unicode
from aam.options import *

from jinja2 import Environment, FileSystemLoader, TemplateNotFound

def render():
    env = Environment(
        loader=FileSystemLoader(hub.root.template_path),
        autoescape=False
    )
    env.globals.update(
        title = hub.site.name,
        site_url = hub.site.url,
        site_name = hub.site.name,
        site_owner = hub.site.owner,
        pages = hub.site.pages,
    )
    for page in hub.site.pages:
        output_path = os.path.join(hub.site.path, "deploy/%s" % page['title'].strip().replace(' ','') + ".html")
        html = to_unicode(env.get_template("page.html").render(
            title = hub.site.name + " | " + page['title'],
            page = page,
            ))
        with open(output_path, "w") as f:
            f.write(html)
    home = to_unicode(env.get_template("home.html").render())
    output_path = os.path.join(hub.site.path, "deploy/home.html")
    with open(output_path, "w") as f:
        f.write(home)